grib2io.tables.section4_discipline0 API documentation

# grib2io.tables.section4_discipline0

View Source

      1table_4_2_0_0  = {
      2'0':['Temperature','K','TMP'],
      3'1':['Virtual Temperature','K','VTMP'],
      4'2':['Potential Temperature','K','POT'],
      5'3':['Pseudo-Adiabatic Potential Temperature (or Equivalent Potential Temperature)','K','EPOT'],
      6'4':['Maximum Temperature','K','TMAX'],
      7'5':['Minimum Temperature','K','TMIN'],
      8'6':['Dew Point Temperature','K','DPT'],
      9'7':['Dew Point Depression (or Deficit)','K','DEPR'],
     10'8':['Lapse Rate','K m-1','LAPR'],
     11'9':['Temperature Anomaly','K','TMPA'],
     12'10':['Latent Heat Net Flux','W m-2','LHTFL'],
     13'11':['Sensible Heat Net Flux','W m-2','SHTFL'],
     14'12':['Heat Index','K','HEATX'],
     15'13':['Wind Chill Factor','K','WCF'],
     16'14':['Minimum Dew Point Depression','K','MINDPD'],
     17'15':['Virtual Potential Temperature','K','VPTMP'],
     18'16':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
     19'17':['Skin Temperature','K','SKINT'],
     20'18':['Snow Temperature (top of snow)','K','SNOT'],
     21'19':['Turbulent Transfer Coefficient for Heat','Numeric','TTCHT'],
     22'20':['Turbulent Diffusion Coefficient for Heat','m2s-1','TDCHT'],
     23'21':['Apparent Temperature','K','APTMP'],
     24'22':['Temperature Tendency due to Short-Wave Radiation','K s-1','TTSWR'],
     25'23':['Temperature Tendency due to Long-Wave Radiation','K s-1','TTLWR'],
     26'24':['Temperature Tendency due to Short-Wave Radiation, Clear Sky','K s-1','TTSWRCS'],
     27'25':['Temperature Tendency due to Long-Wave Radiation, Clear Sky','K s-1','TTLWRCS'],
     28'26':['Temperature Tendency due to parameterizations','K s-1','TTPARM'],
     29'27':['Wet Bulb Temperature','K','WETBT'],
     30'28':['Unbalanced Component of Temperature','K','UCTMP'],
     31'29':['Temperature Advection','K s-1','TMPADV'],
     32'30':['Latent Heat Net Flux Due to Evaporation','W m-2','LHFLXE'],
     33'31':['Latent Heat Net Flux Due to Sublimation','W m-2','LHFLXS'],
     34'32':['Wet-Bulb Potential Temperature','K','WETBPT'],
     35'33-191':['Reserved','unknown','unknown'],
     36'192-254':['Reserved for Local Use','unknown','unknown'],
     37'192':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
     38'193':['Temperature Tendency by All Radiation','K s-1','TTRAD'],
     39'194':['Relative Error Variance','unknown','REV'],
     40'195':['Large Scale Condensate Heating Rate','K s-1','LRGHR'],
     41'196':['Deep Convective Heating Rate','K s-1','CNVHR'],
     42'197':['Total Downward Heat Flux at Surface','W m-2','THFLX'],
     43'198':['Temperature Tendency by All Physics','K s-1','TTDIA'],
     44'199':['Temperature Tendency by Non-radiation Physics','K s-1','TTPHY'],
     45'200':['Standard Dev. of IR Temp. over 1x1 deg. area','K','TSD1D'],
     46'201':['Shallow Convective Heating Rate','K s-1','SHAHR'],
     47'202':['Vertical Diffusion Heating rate','K s-1','VDFHR'],
     48'203':['Potential Temperature at Top of Viscous Sublayer','K','THZ0'],
     49'204':['Tropical Cyclone Heat Potential','Jm-2K','TCHP'],
     50'205':['Effective Layer (EL) Temperature','C','ELMELT'],
     51'206':['Wet Bulb Globe Temperature','K','WETGLBT'],
     52'255':['Missing','unknown','unknown'],
     53}
     54table_4_2_0_1  = {
     55'0':['Specific Humidity','kg kg-1','SPFH'],
     56'1':['Relative Humidity','%','RH'],
     57'2':['Humidity Mixing Ratio','kg kg-1','MIXR'],
     58'3':['Precipitable Water','kg m-2','PWAT'],
     59'4':['Vapour Pressure','Pa','VAPP'],
     60'5':['Saturation Deficit','Pa','SATD'],
     61'6':['Evaporation','kg m-2','EVP'],
     62'7':['Precipitation Rate','kg m-2 s-1','PRATE'],
     63'8':['Total Precipitation','kg m-2','APCP'],
     64'9':['Large-Scale Precipitation (non-convective)','kg m-2','NCPCP'],
     65'10':['Convective Precipitation','kg m-2','ACPCP'],
     66'11':['Snow Depth','m','SNOD'],
     67'12':['Snowfall Rate Water Equivalent','kg m-2 s-1','SRWEQ'],
     68'13':['Water Equivalent of Accumulated Snow Depth','kg m-2','WEASD'],
     69'14':['Convective Snow','kg m-2','SNOC'],
     70'15':['Large-Scale Snow','kg m-2','SNOL'],
     71'16':['Snow Melt','kg m-2','SNOM'],
     72'17':['Snow Age','day','SNOAG'],
     73'18':['Absolute Humidity','kg m-3','ABSH'],
     74'19':['Precipitation Type','See Table 4.201','PTYPE'],
     75'20':['Integrated Liquid Water','kg m-2','ILIQW'],
     76'21':['Condensate','kg kg-1','TCOND'],
     77'22':['Cloud Mixing Ratio','kg kg-1','CLMR'],
     78'23':['Ice Water Mixing Ratio','kg kg-1','ICMR'],
     79'24':['Rain Mixing Ratio','kg kg-1','RWMR'],
     80'25':['Snow Mixing Ratio','kg kg-1','SNMR'],
     81'26':['Horizontal Moisture Convergence','kg kg-1 s-1','MCONV'],
     82'27':['Maximum Relative Humidity','%','MAXRH'],
     83'28':['Maximum Absolute Humidity','kg m-3','MAXAH'],
     84'29':['Total Snowfall','m','ASNOW'],
     85'30':['Precipitable Water Category','See Table 4.202','PWCAT'],
     86'31':['Hail','m','HAIL'],
     87'32':['Graupel','kg kg-1','GRLE'],
     88'33':['Categorical Rain','Code table 4.222','CRAIN'],
     89'34':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
     90'35':['Categorical Ice Pellets','Code table 4.222','CICEP'],
     91'36':['Categorical Snow','Code table 4.222','CSNOW'],
     92'37':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
     93'38':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIVER'],
     94'39':['Percent frozen precipitation','%','CPOFP'],
     95'40':['Potential Evaporation','kg m-2','PEVAP'],
     96'41':['Potential Evaporation Rate','W m-2','PEVPR'],
     97'42':['Snow Cover','%','SNOWC'],
     98'43':['Rain Fraction of Total Cloud Water','Proportion','FRAIN'],
     99'44':['Rime Factor','Numeric','RIME'],
    100'45':['Total Column Integrated Rain','kg m-2','TCOLR'],
    101'46':['Total Column Integrated Snow','kg m-2','TCOLS'],
    102'47':['Large Scale Water Precipitation (Non-Convective)','kg m-2','LSWP'],
    103'48':['Convective Water Precipitation','kg m-2','CWP'],
    104'49':['Total Water Precipitation','kg m-2','TWATP'],
    105'50':['Total Snow Precipitation','kg m-2','TSNOWP'],
    106'51':['Total Column Water (Vertically integrated total water (vapour+cloud water/ice)','kg m-2','TCWAT'],
    107'52':['Total Precipitation Rate','kg m-2 s-1','TPRATE'],
    108'53':['Total Snowfall Rate Water Equivalent','kg m-2 s-1','TSRWE'],
    109'54':['Large Scale Precipitation Rate','kg m-2 s-1','LSPRATE'],
    110'55':['Convective Snowfall Rate Water Equivalent','kg m-2 s-1','CSRWE'],
    111'56':['Large Scale Snowfall Rate Water Equivalent','kg m-2 s-1','LSSRWE'],
    112'57':['Total Snowfall Rate','m s-1','TSRATE'],
    113'58':['Convective Snowfall Rate','m s-1','CSRATE'],
    114'59':['Large Scale Snowfall Rate','m s-1','LSSRATE'],
    115'60':['Snow Depth Water Equivalent','kg m-2','SDWE'],
    116'61':['Snow Density','kg m-3','SDEN'],
    117'62':['Snow Evaporation','kg m-2','SEVAP'],
    118'63':['Reserved','unknown','unknown'],
    119'64':['Total Column Integrated Water Vapour','kg m-2','TCIWV'],
    120'65':['Rain Precipitation Rate','kg m-2 s-1','RPRATE'],
    121'66':['Snow Precipitation Rate','kg m-2 s-1','SPRATE'],
    122'67':['Freezing Rain Precipitation Rate','kg m-2 s-1','FPRATE'],
    123'68':['Ice Pellets Precipitation Rate','kg m-2 s-1','IPRATE'],
    124'69':['Total Column Integrate Cloud Water','kg m-2','TCOLW'],
    125'70':['Total Column Integrate Cloud Ice','kg m-2','TCOLI'],
    126'71':['Hail Mixing Ratio','kg kg-1','HAILMXR'],
    127'72':['Total Column Integrate Hail','kg m-2','TCOLH'],
    128'73':['Hail Prepitation Rate','kg m-2 s-1','HAILPR'],
    129'74':['Total Column Integrate Graupel','kg m-2','TCOLG'],
    130'75':['Graupel (Snow Pellets) Prepitation Rate','kg m-2 s-1','GPRATE'],
    131'76':['Convective Rain Rate','kg m-2 s-1','CRRATE'],
    132'77':['Large Scale Rain Rate','kg m-2 s-1','LSRRATE'],
    133'78':['Total Column Integrate Water (All components including precipitation)','kg m-2','TCOLWA'],
    134'79':['Evaporation Rate','kg m-2 s-1','EVARATE'],
    135'80':['Total Condensate','kg kg-1','TOTCON'],
    136'81':['Total Column-Integrate Condensate','kg m-2','TCICON'],
    137'82':['Cloud Ice Mixing Ratio','kg kg-1','CIMIXR'],
    138'83':['Specific Cloud Liquid Water Content','kg kg-1','SCLLWC'],
    139'84':['Specific Cloud Ice Water Content','kg kg-1','SCLIWC'],
    140'85':['Specific Rain Water Content','kg kg-1','SRAINW'],
    141'86':['Specific Snow Water Content','kg kg-1','SSNOWW'],
    142'87':['Stratiform Precipitation Rate','kg m-2 s-1','STRPRATE'],
    143'88':['Categorical Convective Precipitation','Code table 4.222','CATCP'],
    144'89':['Reserved','unknown','unknown'],
    145'90':['Total Kinematic Moisture Flux','kg kg-1 m s-1','TKMFLX'],
    146'91':['U-component (zonal) Kinematic Moisture Flux','kg kg-1 m s-1','UKMFLX'],
    147'92':['V-component (meridional) Kinematic Moisture Flux','kg kg-1 m s-1','VKMFLX'],
    148'93':['Relative Humidity With Respect to Water','%','RHWATER'],
    149'94':['Relative Humidity With Respect to Ice','%','RHICE'],
    150'95':['Freezing or Frozen Precipitation Rate','kg m-2 s-1','FZPRATE'],
    151'96':['Mass Density of Rain','kg m-3','MASSDR'],
    152'97':['Mass Density of Snow','kg m-3','MASSDS'],
    153'98':['Mass Density of Graupel','kg m-3','MASSDG'],
    154'99':['Mass Density of Hail','kg m-3','MASSDH'],
    155'100':['Specific Number Concentration of Rain','kg-1','SPNCR'],
    156'101':['Specific Number Concentration of Snow','kg-1','SPNCS'],
    157'102':['Specific Number Concentration of Graupel','kg-1','SPNCG'],
    158'103':['Specific Number Concentration of Hail','kg-1','SPNCH'],
    159'104':['Number Density of Rain','m-3','NUMDR'],
    160'105':['Number Density of Snow','m-3','NUMDS'],
    161'106':['Number Density of Graupel','m-3','NUMDG'],
    162'107':['Number Density of Hail','m-3','NUMDH'],
    163'108':['Specific Humidity Tendency due to Parameterizations','kg kg-1 s-1','SHTPRM'],
    164'109':['Mass Density of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWHVA'],
    165'110':['Specific Mass of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWHMA'],
    166'111':['Mass Mixing Ratio of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWHDA'],
    167'112':['Mass Density of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWGVA'],
    168'113':['Specific Mass of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWGMA'],
    169'114':['Mass Mixing Ratio of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWGDA'],
    170'115':['Mass Density of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWSVA'],
    171'116':['Specific Mass of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWSMA'],
    172'117':['Mass Mixing Ratio of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWSDA'],
    173'118':['Unbalanced Component of Specific Humidity','kg kg-1','UNCSH'],
    174'119':['Unbalanced Component of Specific Cloud Liquid Water content','kg kg-1','UCSCLW'],
    175'120':['Unbalanced Component of Specific Cloud Ice Water content','kg kg-1','UCSCIW'],
    176'121':['Fraction of Snow Cover','Proportion','FSNOWC'],
    177'122':['Precipitation intensity index','See Table 4.247','PIIDX'],
    178'123':['Domiunknownt precipitation type','See Table 4.201','DPTYPE'],
    179'124':['Presence of showers','See Table 4.222','PSHOW'],
    180'125':['Presence of blowing snow','See Table 4.222','PBSNOW'],
    181'126':['Presence of blizzard','See Table 4.222','PBLIZZ'],
    182'127':['Ice pellets (non-water equivalent) precipitation rate','m s-1','ICEP'],
    183'128':['Total solid precipitation rate','kg m-2 s-1','TSPRATE'],
    184'129':['Effective radius of cloud water','m','ERADCW'],
    185'130':['Effective radius of rain','m','ERADRAIN'],
    186'131':['Effective radius of cloud ice','m','ERADCICE'],
    187'132':['Effective radius of snow','m','ERADSNOW'],
    188'133':['Effective radius of graupel','m','ERADGRL'],
    189'134':['Effective radius of hail','m','ERADHAIL'],
    190'135':['Effective radius of subgrid liquid clouds','m','ERADSLC'],
    191'136':['Effective radius of subgrid ice clouds','m','ERADSIC'],
    192'137':['Effective aspect ratio of rain','unknown','ERATIOR'],
    193'138':['Effective aspect ratio of cloud ice','unknown','ERATIOCI'],
    194'139':['Effective aspect ratio of snow','unknown','ERATIOS'],
    195'140':['Effective aspect ratio of graupel','unknown','ERATIOG'],
    196'141':['Effective aspect ratio of hail','unknown','ERATIOH'],
    197'142':['Effective ratio of subgrid ice clouds','unknown','ERATOSIC'],
    198'143':['Potential evaporation rate','kg m-2 s-1','PERATE'],
    199'144':['Specific rain water content (convective)','kg kg-1','SRWATERC'],
    200'145':['Specific snow water content (convective)','kg kg-1','SSNOWWC'],
    201'146':['Cloud ice precipitation rate','kg m-2 s-1','CICEPR'],
    202'147':['Character of precipitation','See Table 4.249','PERATE'],
    203'148':['Snow evaporation rate','kg m-2 s-1','SNOWERAT'],
    204'149':['Cloud water mixing ratio','kg kg-1','CWATERMR'],
    205'150-128':['Reserved','unknown','unknown'],
    206'129':['Effective Radius of Cloud Water','m','EFRCWAT'],
    207'130':['Effective Radius of Rain','m','EFRRAIN'],
    208'131':['Effective Radius of Cloud Ice','m','EFRCICE'],
    209'132':['Effective Radius of Snow','m','EFRSNOW'],
    210'133':['Effective Radius of Graupel','m','EFRGRL'],
    211'134':['Effective Radius of Hail','m','EFRHAIL'],
    212'135':['Effective Radius of Subgrid Liquid Clouds','m','EFRSLC'],
    213'136':['Effective Radius of Subgrid Ice Clouds','m','EFRSICEC'],
    214'137':['Effective Aspect Ratio of Rain','unknown','EFARRAIN'],
    215'138':['Effective Aspect Ratio of Cloud Ice','unknown','EFARCICE'],
    216'139':['Effective Aspect Ratio of Snow','unknown','EFARSNOW'],
    217'140':['Effective Aspect Ratio of Graupel','unknown','EFARGRL'],
    218'141':['Effective Aspect Ratio of Hail','unknown','EFARHAIL'],
    219'142':['Effective Aspect Ratio of Subgrid Ice Clouds','unknown','EFARSIC'],
    220'143-191':['Reserved','unknown','unknown'],
    221'192-254':['Reserved for Local Use','unknown','unknown'],
    222'192':['Categorical Rain','Code table 4.222','CRAIN'],
    223'193':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
    224'194':['Categorical Ice Pellets','Code table 4.222','CICEP'],
    225'195':['Categorical Snow','Code table 4.222','CSNOW'],
    226'196':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
    227'197':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIV'],
    228'198':['Minimum Relative Humidity','%','MINRH'],
    229'199':['Potential Evaporation','kg m-2','PEVAP'],
    230'200':['Potential Evaporation Rate','W m-2','PEVPR'],
    231'201':['Snow Cover','%','SNOWC'],
    232'202':['Rain Fraction of Total Liquid Water','non-dim','FRAIN'],
    233'203':['Rime Factor','non-dim','RIME'],
    234'204':['Total Column Integrated Rain','kg m-2','TCOLR'],
    235'205':['Total Column Integrated Snow','kg m-2','TCOLS'],
    236'206':['Total Icing Potential Diagnostic','non-dim','TIPD'],
    237'207':['Number concentration for ice particles','non-dim','NCIP'],
    238'208':['Snow temperature','K','SNOT'],
    239'209':['Total column-integrated supercooled liquid water','kg m-2','TCLSW'],
    240'210':['Total column-integrated melting ice','kg m-2','TCOLM'],
    241'211':['Evaporation - Precipitation','cm/day','EMNP'],
    242'212':['Sublimation (evaporation from snow)','W m-2','SBSNO'],
    243'213':['Deep Convective Moistening Rate','kg kg-1 s-1','CNVMR'],
    244'214':['Shallow Convective Moistening Rate','kg kg-1 s-1','SHAMR'],
    245'215':['Vertical Diffusion Moistening Rate','kg kg-1 s-1','VDFMR'],
    246'216':['Condensation Pressure of Parcali Lifted From Indicate Surface','Pa','CONDP'],
    247'217':['Large scale moistening rate','kg kg-1 s-1','LRGMR'],
    248'218':['Specific humidity at top of viscous sublayer','kg kg-1','QZ0'],
    249'219':['Maximum specific humidity at 2m','kg kg-1','QMAX'],
    250'220':['Minimum specific humidity at 2m','kg kg-1','QMIN'],
    251'221':['Liquid precipitation (Rainfall)','kg m-2','ARAIN'],
    252'222':['Snow temperature, depth-avg','K','SNOWT'],
    253'223':['Total precipitation (nearest grid point)','kg m-2','APCPN'],
    254'224':['Convective precipitation (nearest grid point)','kg m-2','ACPCPN'],
    255'225':['Freezing Rain','kg m-2','FRZR'],
    256'226':['Predominant Weather','Numeric','PWTHER'],
    257'227':['Frozen Rain','kg m-2','FROZR'],
    258'228':['Flat Ice Accumulation (FRAM)','kg m-2','FICEAC'],
    259'229':['Line Ice Accumulation (FRAM)','kg m-2','LICEAC'],
    260'230':['Sleet Accumulation','kg m-2','SLACC'],
    261'231':['Precipitation Potential Index','%','PPINDX'],
    262'232':['Probability Cloud Ice Present','%','PROBCIP'],
    263'233':['Snow Liquid ratio','kg kg-1','SNOWLR'],
    264'234':['Precipitation Duration','hour','PCPDUR'],
    265'235':['Cloud Liquid Mixing Ratio','kg kg-1','CLLMR'],
    266'236-240':['Reserved','unknown','unknown'],
    267'241':['Total Snow','kg m-2','TSNOW'],
    268'242':['Relative Humidity with Respect to Precipitable Water','%','RHPW'],
    269'245':['Hourly Maximum of Column Vertical Integrated Graupel on Entire Atmosphere','kg m-2','MAXVIG'],
    270'255':['Missing','unknown','unknown'],
    271}
    272table_4_2_0_2  = {
    273'0':['Wind Direction (from which blowing)','°','WDIR'],
    274'1':['Wind Speed','m s-1','WIND'],
    275'2':['U-Component of Wind','m s-1','UGRD'],
    276'3':['V-Component of Wind','m s-1','VGRD'],
    277'4':['Stream Function','m2 s-1','STRM'],
    278'5':['Velocity Potential','m2 s-1','VPOT'],
    279'6':['Montgomery Stream Function','m2 s-2','MNTSF'],
    280'7':['Sigma Coordinate Vertical Velocity','s-1','SGCVV'],
    281'8':['Vertical Velocity (Pressure)','Pa s-1','VVEL'],
    282'9':['Vertical Velocity (Geometric)','m s-1','DZDT'],
    283'10':['Absolute Vorticity','s-1','ABSV'],
    284'11':['Absolute Divergence','s-1','ABSD'],
    285'12':['Relative Vorticity','s-1','RELV'],
    286'13':['Relative Divergence','s-1','RELD'],
    287'14':['Potential Vorticity','K m2 kg-1 s-1','PVORT'],
    288'15':['Vertical U-Component Shear','s-1','VUCSH'],
    289'16':['Vertical V-Component Shear','s-1','VVCSH'],
    290'17':['Momentum Flux, U-Component','N m-2','UFLX'],
    291'18':['Momentum Flux, V-Component','N m-2','VFLX'],
    292'19':['Wind Mixing Energy','J','WMIXE'],
    293'20':['Boundary Layer Dissipation','W m-2','BLYDP'],
    294'21':['Maximum Wind Speed','m s-1','MAXGUST'],
    295'22':['Wind Speed (Gust)','m s-1','GUST'],
    296'23':['U-Component of Wind (Gust)','m s-1','UGUST'],
    297'24':['V-Component of Wind (Gust)','m s-1','VGUST'],
    298'25':['Vertical Speed Shear','s-1','VWSH'],
    299'26':['Horizontal Momentum Flux','N m-2','MFLX'],
    300'27':['U-Component Storm Motion','m s-1','USTM'],
    301'28':['V-Component Storm Motion','m s-1','VSTM'],
    302'29':['Drag Coefficient','Numeric','CD'],
    303'30':['Frictional Velocity','m s-1','FRICV'],
    304'31':['Turbulent Diffusion Coefficient for Momentum','m2 s-1','TDCMOM'],
    305'32':['Eta Coordinate Vertical Velocity','s-1','ETACVV'],
    306'33':['Wind Fetch','m','WINDF'],
    307'34':['Normal Wind Component','m s-1','NWIND'],
    308'35':['Tangential Wind Component','m s-1','TWIND'],
    309'36':['Amplitude Function for Rossby Wave Envelope for Meridional Wind','m s-1','AFRWE'],
    310'37':['Northward Turbulent Surface Stress','N m-2 s','NTSS'],
    311'38':['Eastward Turbulent Surface Stress','N m-2 s','ETSS'],
    312'39':['Eastward Wind Tendency Due to Parameterizations','m s-2','EWTPARM'],
    313'40':['Northward Wind Tendency Due to Parameterizations','m s-2','NWTPARM'],
    314'41':['U-Component of Geostrophic Wind','m s-1','UGWIND'],
    315'42':['V-Component of Geostrophic Wind','m s-1','VGWIND'],
    316'43':['Geostrophic Wind Direction','°','GEOWD'],
    317'44':['Geostrophic Wind Speed','m s-1','GEOWS'],
    318'45':['Unbalanced Component of Divergence','s-1','UNDIV'],
    319'46':['Vorticity Advection','s-2','VORTADV'],
    320'47':['Surface roughness for heat,(see Note 5)','m','SFRHEAT'],
    321'48':['Surface roughness for moisture,(see Note 6)','m','SFRMOIST'],
    322'49-191':['Reserved','unknown','unknown'],
    323'192-254':['Reserved for Local Use','unknown','unknown'],
    324'192':['Vertical Speed Shear','s-1','VWSH'],
    325'193':['Horizontal Momentum Flux','N m-2','MFLX'],
    326'194':['U-Component Storm Motion','m s-1','USTM'],
    327'195':['V-Component Storm Motion','m s-1','VSTM'],
    328'196':['Drag Coefficient','non-dim','CD'],
    329'197':['Frictional Velocity','m s-1','FRICV'],
    330'198':['Latitude of U Wind Component of Velocity','deg','LAUV'],
    331'199':['Longitude of U Wind Component of Velocity','deg','LOUV'],
    332'200':['Latitude of V Wind Component of Velocity','deg','LAVV'],
    333'201':['Longitude of V Wind Component of Velocity','deg','LOVV'],
    334'202':['Latitude of Presure Point','deg','LAPP'],
    335'203':['Longitude of Presure Point','deg','LOPP'],
    336'204':['Vertical Eddy Diffusivity Heat exchange','m2 s-1','VEDH'],
    337'205':['Covariance between Meridional and Zonal Components of the wind.','m2 s-2','COVMZ'],
    338'206':['Covariance between Temperature and Zonal Components of the wind.','K*m s-1','COVTZ'],
    339'207':['Covariance between Temperature and Meridional Components of the wind.','K*m s-1','COVTM'],
    340'208':['Vertical Diffusion Zonal Acceleration','m s-2','VDFUA'],
    341'209':['Vertical Diffusion Meridional Acceleration','m s-2','VDFVA'],
    342'210':['Gravity wave drag zonal acceleration','m s-2','GWDU'],
    343'211':['Gravity wave drag meridional acceleration','m s-2','GWDV'],
    344'212':['Convective zonal momentum mixing acceleration','m s-2','CNVU'],
    345'213':['Convective meridional momentum mixing acceleration','m s-2','CNVV'],
    346'214':['Tendency of vertical velocity','m s-2','WTEND'],
    347'215':['Omega (Dp/Dt) divide by density','K','OMGALF'],
    348'216':['Convective Gravity wave drag zonal acceleration','m s-2','CNGWDU'],
    349'217':['Convective Gravity wave drag meridional acceleration','m s-2','CNGWDV'],
    350'218':['Velocity Point Model Surface','unknown','LMV'],
    351'219':['Potential Vorticity (Mass-Weighted)','1/s/m','PVMWW'],
    352'220':['Hourly Maximum of Upward Vertical Velocity','m s-1','MAXUVV'],
    353'221':['Hourly Maximum of Downward Vertical Velocity','m s-1','MAXDVV'],
    354'222':['U Component of Hourly Maximum 10m Wind Speed','m s-1','MAXUW'],
    355'223':['V Component of Hourly Maximum 10m Wind Speed','m s-1','MAXVW'],
    356'224':['Ventilation Rate','m2 s-1','VRATE'],
    357'225':['Transport Wind Speed','m s-1','TRWSPD'],
    358'226':['Transport Wind Direction','Deg','TRWDIR'],
    359'227':['Earliest Reasonable Arrival Time (10% exceedance)','s','TOA10'],
    360'228':['Most Likely Arrival Time (50% exceedance)','s','TOA50'],
    361'229':['Most Likely Departure Time (50% exceedance)','s','TOD50'],
    362'230':['Latest Reasonable Departure Time (90% exceedance)','s','TOD90'],
    363'231':['Tropical Wind Direction','°','TPWDIR'],
    364'232':['Tropical Wind Speed','m s-1','TPWSPD'],
    365'233':['Inflow Based (ESFC) to 50% EL Shear Magnitude','kt','ESHR'],
    366'234':['U Component Inflow Based to 50% EL Shear Vector','kt','UESH'],
    367'235':['V Component Inflow Based to 50% EL Shear Vector','kt','VESH'],
    368'236':['U Component Bunkers Effective Right Motion','kt','UEID'],
    369'237':['V Component Bunkers Effective Right Motion','kt','VEID'],
    370'255':['Missing','unknown','unknown'],
    371}
    372table_4_2_0_3  = {
    373'0':['Pressure','Pa','PRES'],
    374'1':['Pressure Reduced to MSL','Pa','PRMSL'],
    375'2':['Pressure Tendency','Pa s-1','PTEND'],
    376'3':['ICAO Standard Atmosphere Reference Height','m','ICAHT'],
    377'4':['Geopotential','m2 s-2','GP'],
    378'5':['Geopotential Height','gpm','HGT'],
    379'6':['Geometric Height','m','DIST'],
    380'7':['Standard Deviation of Height','m','HSTDV'],
    381'8':['Pressure Anomaly','Pa','PRESA'],
    382'9':['Geopotential Height Anomaly','gpm','GPA'],
    383'10':['Density','kg m-3','DEN'],
    384'11':['Altimeter Setting','Pa','ALTS'],
    385'12':['Thickness','m','THICK'],
    386'13':['Pressure Altitude','m','PRESALT'],
    387'14':['Density Altitude','m','DENALT'],
    388'15':['5-Wave Geopotential Height','gpm','5WAVH'],
    389'16':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
    390'17':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
    391'18':['Planetary Boundary Layer Height','m','HPBL'],
    392'19':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
    393'20':['Standard Deviation of Sub-Grid Scale Orography','m','SDSGSO'],
    394'21':['Angle of Sub-Grid Scale Orography','rad','AOSGSO'],
    395'22':['Slope of Sub-Grid Scale Orography','Numeric','SSGSO'],
    396'23':['Gravity Wave Dissipation','W m-2','GWD'],
    397'24':['Anisotropy of Sub-Grid Scale Orography','Numeric','ASGSO'],
    398'25':['Natural Logarithm of Pressure in Pa','Numeric','NLPRES'],
    399'26':['Exner Pressure','Numeric','EXPRES'],
    400'27':['Updraught Mass Flux','kg m-2 s-1','UMFLX'],
    401'28':['Downdraught Mass Flux','kg m-2 s-1','DMFLX'],
    402'29':['Updraught Detrainment Rate','kg m-3 s-1','UDRATE'],
    403'30':['Downdraught Detrainment Rate','kg m-3 s-1','DDRATE'],
    404'31':['Unbalanced Component of Logarithm of Surface Pressure','unknown','UCLSPRS'],
    405'32':['Saturation water vapour pressure','Pa','SWATERVP'],
    406'33':['Geometric altitude above mean sea level','m','GAMSL'],
    407'34':['Geometric height above ground level','m','GHAGRD'],
    408'35-191':['Reserved','unknown','unknown'],
    409'192-254':['Reserved for Local Use','unknown','unknown'],
    410'192':['MSLP (Eta model reduction)','Pa','MSLET'],
    411'193':['5-Wave Geopotential Height','gpm','5WAVH'],
    412'194':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
    413'195':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
    414'196':['Planetary Boundary Layer Height','m','HPBL'],
    415'197':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
    416'198':['MSLP (MAPS System Reduction)','Pa','MSLMA'],
    417'199':['3-hr pressure tendency (Std. Atmos. Reduction)','Pa s-1','TSLSA'],
    418'200':['Pressure of level from which parcel was lifted','Pa','PLPL'],
    419'201':['X-gradient of Log Pressure','m-1','LPSX'],
    420'202':['Y-gradient of Log Pressure','m-1','LPSY'],
    421'203':['X-gradient of Height','m-1','HGTX'],
    422'204':['Y-gradient of Height','m-1','HGTY'],
    423'205':['Layer Thickness','m','LAYTH'],
    424'206':['Natural Log of Surface Pressure','ln (kPa)','NLGSP'],
    425'207':['Convective updraft mass flux','kg m-2 s-1','CNVUMF'],
    426'208':['Convective downdraft mass flux','kg m-2 s-1','CNVDMF'],
    427'209':['Convective detrainment mass flux','kg m-2 s-1','CNVDEMF'],
    428'210':['Mass Point Model Surface','unknown','LMH'],
    429'211':['Geopotential Height (nearest grid point)','gpm','HGTN'],
    430'212':['Pressure (nearest grid point)','Pa','PRESN'],
    431'213':['Orographic Convexity','unknown','ORCONV'],
    432'214':['Orographic Asymmetry, W Component','unknown','ORASW'],
    433'215':['Orographic Asymmetry, S Component','unknown','ORASS'],
    434'216':['Orographic Asymmetry, SW Component','unknown','ORASSW'],
    435'217':['Orographic Asymmetry, NW Component','unknown','ORASNW'],
    436'218':['Orographic Length Scale, W Component','unknown','ORLSW'],
    437'219':['Orographic Length Scale, S Component','unknown','ORLSS'],
    438'220':['Orographic Length Scale, SW Component','unknown','ORLSSW'],
    439'221':['Orographic Length Scale, NW Component','unknown','ORLSNW'],
    440'222':['Effective Surface Height','m','EFSH'],
    441'255':['Missing','unknown','unknown'],
    442}
    443table_4_2_0_4  = {
    444'0':['Net Short-Wave Radiation Flux (Surface)','W m-2','NSWRS'],
    445'1':['Net Short-Wave Radiation Flux (Top of Atmosphere)','W m-2','NSWRT'],
    446'2':['Short-Wave Radiation Flux','W m-2','SWAVR'],
    447'3':['Global Radiation Flux','W m-2','GRAD'],
    448'4':['Brightness Temperature','K','BRTMP'],
    449'5':['Radiance (with respect to wave number)','W m-1 sr-1','LWRAD'],
    450'6':['Radiance (with respect to wavelength)','W m-3 sr-1','SWRAD'],
    451'7':['Downward Short-Wave Radiation Flux','W m-2','DSWRF'],
    452'8':['Upward Short-Wave Radiation Flux','W m-2','USWRF'],
    453'9':['Net Short Wave Radiation Flux','W m-2','NSWRF'],
    454'10':['Photosynthetically Active Radiation','W m-2','PHOTAR'],
    455'11':['Net Short-Wave Radiation Flux, Clear Sky','W m-2','NSWRFCS'],
    456'12':['Downward UV Radiation','W m-2','DWUVR'],
    457'13':['Direct Short Wave Radiation Flux','W m-2','DSWRFLX'],
    458'14':['Diffuse Short Wave Radiation Flux','W m-2','DIFSWRF'],
    459'15-49':['Reserved','unknown','unknown'],
    460'50':['UV Index (Under Clear Sky)','Numeric','UVIUCS'],
    461'51':['UV Index','Numeric','UVI'],
    462'52':['Downward Short-Wave Radiation Flux, Clear Sky','W m-2','DSWRFCS'],
    463'53':['Upward Short-Wave Radiation Flux, Clear Sky','W m-2','USWRFCS'],
    464'54':['Direct normal short-wave radiation flux,(see Note 3)','W m-2','DSWRFLX'],
    465'55-191':['Reserved','unknown','unknown'],
    466'192-254':['Reserved for Local Use','unknown','unknown'],
    467'192':['Downward Short-Wave Radiation Flux','W m-2','DSWRF'],
    468'193':['Upward Short-Wave Radiation Flux','W m-2','USWRF'],
    469'194':['UV-B Downward Solar Flux','W m-2','DUVB'],
    470'195':['Clear sky UV-B Downward Solar Flux','W m-2','CDUVB'],
    471'196':['Clear Sky Downward Solar Flux','W m-2','CSDSF'],
    472'197':['Solar Radiative Heating Rate','K s-1','SWHR'],
    473'198':['Clear Sky Upward Solar Flux','W m-2','CSUSF'],
    474'199':['Cloud Forcing Net Solar Flux','W m-2','CFNSF'],
    475'200':['Visible Beam Downward Solar Flux','W m-2','VBDSF'],
    476'201':['Visible Diffuse Downward Solar Flux','W m-2','VDDSF'],
    477'202':['Near IR Beam Downward Solar Flux','W m-2','NBDSF'],
    478'203':['Near IR Diffuse Downward Solar Flux','W m-2','NDDSF'],
    479'204':['Downward Total Radiation Flux','W m-2','DTRF'],
    480'205':['Upward Total Radiation Flux','W m-2','UTRF'],
    481'255':['Missing','unknown','unknown'],
    482}
    483table_4_2_0_5  = {
    484'0':['Net Long-Wave Radiation Flux (Surface)','W m-2','NLWRS'],
    485'1':['Net Long-Wave Radiation Flux (Top of Atmosphere)','W m-2','NLWRT'],
    486'2':['Long-Wave Radiation Flux','W m-2','LWAVR'],
    487'3':['Downward Long-Wave Rad. Flux','W m-2','DLWRF'],
    488'4':['Upward Long-Wave Rad. Flux','W m-2','ULWRF'],
    489'5':['Net Long-Wave Radiation Flux','W m-2','NLWRF'],
    490'6':['Net Long-Wave Radiation Flux, Clear Sky','W m-2','NLWRCS'],
    491'7':['Brightness Temperature','K','BRTEMP'],
    492'8':['Downward Long-Wave Radiation Flux, Clear Sky','W m-2','DLWRFCS'],
    493'9-191':['Reserved','unknown','unknown'],
    494'192-254':['Reserved for Local Use','unknown','unknown'],
    495'192':['Downward Long-Wave Rad. Flux','W m-2','DLWRF'],
    496'193':['Upward Long-Wave Rad. Flux','W m-2','ULWRF'],
    497'194':['Long-Wave Radiative Heating Rate','K s-1','LWHR'],
    498'195':['Clear Sky Upward Long Wave Flux','W m-2','CSULF'],
    499'196':['Clear Sky Downward Long Wave Flux','W m-2','CSDLF'],
    500'197':['Cloud Forcing Net Long Wave Flux','W m-2','CFNLF'],
    501'255':['Missing','unknown','unknown'],
    502}
    503table_4_2_0_6  = {
    504'0':['Cloud Ice','kg m-2','CICE'],
    505'1':['Total Cloud Cover','%','TCDC'],
    506'2':['Convective Cloud Cover','%','CDCON'],
    507'3':['Low Cloud Cover','%','LCDC'],
    508'4':['Medium Cloud Cover','%','MCDC'],
    509'5':['High Cloud Cover','%','HCDC'],
    510'6':['Cloud Water','kg m-2','CWAT'],
    511'7':['Cloud Amount','%','CDCA'],
    512'8':['Cloud Type','See Table 4.203','CDCT'],
    513'9':['Thunderstorm Maximum Tops','m','TMAXT'],
    514'10':['Thunderstorm Coverage','See Table 4.204','THUNC'],
    515'11':['Cloud Base','m','CDCB'],
    516'12':['Cloud Top','m','CDCTOP'],
    517'13':['Ceiling','m','CEIL'],
    518'14':['Non-Convective Cloud Cover','%','CDLYR'],
    519'15':['Cloud Work Function','J kg-1','CWORK'],
    520'16':['Convective Cloud Efficiency','Proportion','CUEFI'],
    521'17':['Total Condensate','kg kg-1','TCONDO'],
    522'18':['Total Column-Integrated Cloud Water','kg m-2','TCOLWO'],
    523'19':['Total Column-Integrated Cloud Ice','kg m-2','TCOLIO'],
    524'20':['Total Column-Integrated Condensate','kg m-2','TCOLC'],
    525'21':['Ice fraction of total condensate','Proportion','FICE'],
    526'22':['Cloud Cover','%','CDCC'],
    527'23':['Cloud Ice Mixing Ratio','kg kg-1','CDCIMR'],
    528'24':['Sunshine','Numeric','SUNS'],
    529'25':['Horizontal Extent of Cumulonimbus (CB)','%','CBHE'],
    530'26':['Height of Convective Cloud Base','m','HCONCB'],
    531'27':['Height of Convective Cloud Top','m','HCONCT'],
    532'28':['Number Concentration of Cloud Droplets','kg-1','NCONCD'],
    533'29':['Number Concentration of Cloud Ice','kg-1','NCCICE'],
    534'30':['Number Density of Cloud Droplets','m-3','NDENCD'],
    535'31':['Number Density of Cloud Ice','m-3','NDCICE'],
    536'32':['Fraction of Cloud Cover','Numeric','FRACCC'],
    537'33':['Sunshine Duration','s','SUNSD'],
    538'34':['Surface Long Wave Effective Total Cloudiness','Numeric','SLWTC'],
    539'35':['Surface Short Wave Effective Total Cloudiness','Numeric','SSWTC'],
    540'36':['Fraction of Stratiform Precipitation Cover','Proportion','FSTRPC'],
    541'37':['Fraction of Convective Precipitation Cover','Proportion','FCONPC'],
    542'38':['Mass Density of Cloud Droplets','kg m-3','MASSDCD'],
    543'39':['Mass Density of Cloud Ice','kg m-3','MASSDCI'],
    544'40':['Mass Density of Convective Cloud Water Droplets','kg m-3','MDCCWD'],
    545'41-46':['Reserved','unknown','unknown'],
    546'47':['Volume Fraction of Cloud Water Droplets','Numeric','VFRCWD'],
    547'48':['Volume Fraction of Cloud Ice Particles','Numeric','VFRCICE'],
    548'49':['Volume Fraction of Cloud (Ice and/or Water)','Numeric','VFRCIW'],
    549'50-191':['Reserved','unknown','unknown'],
    550'192-254':['Reserved for Local Use','unknown','unknown'],
    551'192':['Non-Convective Cloud Cover','%','CDLYR'],
    552'193':['Cloud Work Function','J kg-1','CWORK'],
    553'194':['Convective Cloud Efficiency','non-dim','CUEFI'],
    554'195':['Total Condensate','kg kg-1','TCOND'],
    555'196':['Total Column-Integrated Cloud Water','kg m-2','TCOLW'],
    556'197':['Total Column-Integrated Cloud Ice','kg m-2','TCOLI'],
    557'198':['Total Column-Integrated Condensate','kg m-2','TCOLC'],
    558'199':['Ice fraction of total condensate','non-dim','FICE'],
    559'200':['Convective Cloud Mass Flux','Pa s-1','MFLUX'],
    560'201':['Sunshine Duration','s','SUNSD'],
    561'255':['Missing','unknown','unknown'],
    562}
    563table_4_2_0_7  = {
    564'0':['Parcel Lifted Index (to 500 hPa)','K','PLI'],
    565'1':['Best Lifted Index (to 500 hPa)','K','BLI'],
    566'2':['K Index','K','KX'],
    567'3':['KO Index','K','KOX'],
    568'4':['Total Totals Index','K','TOTALX'],
    569'5':['Sweat Index','Numeric','SX'],
    570'6':['Convective Available Potential Energy','J kg-1','CAPE'],
    571'7':['Convective Inhibition','J kg-1','CIN'],
    572'8':['Storm Relative Helicity','m2 s-2','HLCY'],
    573'9':['Energy Helicity Index','Numeric','EHLX'],
    574'10':['Surface Lifted Index','K','LFT X'],
    575'11':['Best (4 layer) Lifted Index','K','4LFTX'],
    576'12':['Richardson Number','Numeric','RI'],
    577'13':['Showalter Index','K','SHWINX'],
    578'14':['Reserved','unknown','unknown'],
    579'15':['Updraft Helicity','m2 s-2','UPHL'],
    580'16':['Bulk Richardson Number','Numeric','BLKRN'],
    581'17':['Gradient Richardson Number','Numeric','GRDRN'],
    582'18':['Flux Richardson Number','Numeric','FLXRN'],
    583'19':['Convective Available Potential Energy Shear','m2 s-2','CONAPES'],
    584'20':['Thunderstorm intensity index','See Table 4.246','TIIDEX'],
    585'21-191':['Reserved','unknown','unknown'],
    586'192-254':['Reserved for Local Use','unknown','unknown'],
    587'192':['Surface Lifted Index','K','LFT X'],
    588'193':['Best (4 layer) Lifted Index','K','4LFTX'],
    589'194':['Richardson Number','Numeric','RI'],
    590'195':['Convective Weather Detection Index','unknown','CWDI'],
    591'196':['Ultra Violet Index','W m-2','UVI'],
    592'197':['Updraft Helicity','m2 s-2','UPHL'],
    593'198':['Leaf Area Index','Numeric','LAI'],
    594'199':['Hourly Maximum of Updraft Helicity','m2 s-2','MXUPHL'],
    595'200':['Hourly Minimum of Updraft Helicity','m2 s-2','MNUPHL'],
    596'201':['Bourgoiun Negative Energy Layer (surface to freezing level)','J kg-1','BNEGELAY'],
    597'202':['Bourgoiun Positive Energy Layer (2k ft AGL to 400 hPa)','J kg-1','BPOSELAY'],
    598'203':['Downdraft CAPE','J kg-1','DCAPE'],
    599'204':['Effective Storm Relative Helicity','m2 s-2','EFHL'],
    600'205':['Enhanced Stretching Potential','Numeric','ESP'],
    601'206':['Critical Angle','Degree','CANGLE'],
    602'207':['Effective Surface Helicity','m2 s-2','E3KH'],
    603'208':['Significant Tornado Parameter with CIN-Effective Layer','numeric','STPC'],
    604'209':['Significant Hail Parameter','numeric','SIGH'],
    605'210':['Supercell Composite Parameter-Effective Layer','numeric','SCCP'],
    606'211':['Significant Tornado parameter-Fixed Layer','numeric','SIGT'],
    607'212':['Mixed Layer (100 mb) Virtual LFC','numeric','MLFC'],
    608'255':['Missing','unknown','unknown'],
    609}
    610table_4_2_0_13  = {
    611'0':['Aerosol Type','See Table 4.205','AEROT'],
    612'1-191':['Reserved','unknown','unknown'],
    613'192-254':['Reserved for Local Use','unknown','unknown'],
    614'192':['Particulate matter (coarse)','µg m-3','PMTC'],
    615'193':['Particulate matter (fine)','µg m-3','PMTF'],
    616'194':['Particulate matter (fine)','log10 (µg m-3)','LPMTF'],
    617'195':['Integrated column particulate matter (fine)','log10 (µg m-3)','LIPMF'],
    618'255':['Missing','unknown','unknown'],
    619}
    620table_4_2_0_14  = {
    621'0':['Total Ozone','DU','TOZNE'],
    622'1':['Ozone Mixing Ratio','kg kg-1','O3MR'],
    623'2':['Total Column Integrated Ozone','DU','TCIOZ'],
    624'3-191':['Reserved','unknown','unknown'],
    625'192-254':['Reserved for Local Use','unknown','unknown'],
    626'192':['Ozone Mixing Ratio','kg kg-1','O3MR'],
    627'193':['Ozone Concentration','ppb','OZCON'],
    628'194':['Categorical Ozone Concentration','Non-Dim','OZCAT'],
    629'195':['Ozone Vertical Diffusion','kg kg-1 s-1','VDFOZ'],
    630'196':['Ozone Production','kg kg-1 s-1','POZ'],
    631'197':['Ozone Tendency','kg kg-1 s-1','TOZ'],
    632'198':['Ozone Production from Temperature Term','kg kg-1 s-1','POZT'],
    633'199':['Ozone Production from Column Ozone Term','kg kg-1 s-1','POZO'],
    634'200':['Ozone Daily Max from 1-hour Average','ppbV','OZMAX1'],
    635'201':['Ozone Daily Max from 8-hour Average','ppbV','OZMAX8'],
    636'202':['PM 2.5 Daily Max from 1-hour Average','μg m-3','PDMAX1'],
    637'203':['PM 2.5 Daily Max from 24-hour Average','μg m-3','PDMAX24'],
    638'204':['Acetaldehyde & Higher Aldehydes','ppbV','ALD2'],
    639'255':['Missing','unknown','unknown'],
    640}
    641table_4_2_0_15  = {
    642'0':['Base Spectrum Width','m s-1','BSWID'],
    643'1':['Base Reflectivity','dB','BREF'],
    644'2':['Base Radial Velocity','m s-1','BRVEL'],
    645'3':['Vertically-Integrated Liquid Water','kg m-2','VIL'],
    646'4':['Layer Maximum Base Reflectivity','dB','LMAXBR'],
    647'5':['Precipitation','kg m-2','PREC'],
    648'6':['Radar Spectra (1)','unknown','RDSP1'],
    649'7':['Radar Spectra (2)','unknown','RDSP2'],
    650'8':['Radar Spectra (3)','unknown','RDSP3'],
    651'9':['Reflectivity of Cloud Droplets','dB','RFCD'],
    652'10':['Reflectivity of Cloud Ice','dB','RFCI'],
    653'11':['Reflectivity of Snow','dB','RFSNOW'],
    654'12':['Reflectivity of Rain','dB','RFRAIN'],
    655'13':['Reflectivity of Graupel','dB','RFGRPL'],
    656'14':['Reflectivity of Hail','dB','RFHAIL'],
    657'15':['Hybrid Scan Reflectivity','dB','HSR'],
    658'16':['Hybrid Scan Reflectivity Height','m','HSRHT'],
    659'17-191':['Reserved','unknown','unknown'],
    660'192-254':['Reserved for Local Use','unknown','unknown'],
    661'255':['Missing','unknown','unknown'],
    662}
    663table_4_2_0_16  = {
    664'0':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
    665'1':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
    666'2':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
    667'3':['Echo Top','m','RETOP'],
    668'4':['Reflectivity','dB','REFD'],
    669'5':['Composite reflectivity','dB','REFC'],
    670'6-191':['Reserved','unknown','unknown'],
    671'192-254':['Reserved for Local Use','unknown','unknown'],
    672'192':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
    673'193':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
    674'194':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
    675'195':['Reflectivity','dB','REFD'],
    676'196':['Composite reflectivity','dB','REFC'],
    677'197':['Echo Top','m','RETOP'],
    678'198':['Hourly Maximum of Simulated Reflectivity','dB','MAXREF'],
    679'255':['Missing','unknown','unknown'],
    680}
    681table_4_2_0_17  = {
    682'0':['Lightning Strike Density','m-2 s-1','LTNGSD'],
    683'1':['Lightning Potential Index (LPI)','J kg-1','LTPINX'],
    684'2':['Cloud-to-Ground Lightning Flash Density','km-2 day-1','CDGDLTFD'],
    685'3':['Cloud-to-Cloud Lightning Flash Density','km-2 day-1','CDCDLTFD'],
    686'4':['Total Lightning Flash Density','km-2 day-1','TLGTFD'],
    687'5':['Subgrid-scale lightning potential index','J kg-1','SLNGPIDX'],
    688'6-191':['Reserved','unknown','unknown'],
    689'192-254':['Reserved for Local Use','unknown','unknown'],
    690'192':['Lightning','non-dim','LTNG'],
    691'255':['Missing','unknown','unknown'],
    692}
    693table_4_2_0_18  = {
    694'0':['Air Concentration of Caesium 137','Bq m-3','ACCES'],
    695'1':['Air Concentration of Iodine 131','Bq m-3','ACIOD'],
    696'2':['Air Concentration of Radioactive Pollutant','Bq m-3','ACRADP'],
    697'3':['Ground Deposition of Caesium 137','Bq m-2','GDCES'],
    698'4':['Ground Deposition of Iodine 131','Bq m-2','GDIOD'],
    699'5':['Ground Deposition of Radioactive Pollutant','Bq m-2','GDRADP'],
    700'6':['Time Integrated Air Concentration of Cesium Pollutant','Bq s m-3','TIACCP'],
    701'7':['Time Integrated Air Concentration of Iodine Pollutant','Bq s m-3','TIACIP'],
    702'8':['Time Integrated Air Concentration of Radioactive Pollutant','Bq s m-3','TIACRP'],
    703'9':['Reserved','unknown','unknown'],
    704'10':['Air Concentration','Bq m-3','AIRCON'],
    705'11':['Wet Deposition','Bq m-2','WETDEP'],
    706'12':['Dry Deposition','Bq m-2','DRYDEP'],
    707'13':['Total Deposition (Wet + Dry)','Bq m-2','TOTLWD'],
    708'14':['Specific Activity Concentration','Bq kg-1','SACON'],
    709'15':['Maximum of Air Concentration in Layer','Bq m-3','MAXACON'],
    710'16':['Height of Maximum of Air Concentration','m','HMXACON'],
    711'17':['Column-Integrated Air Concentration','Bq m-2','CIAIRC'],
    712'18':['Column-Averaged Air Concentration in Layer','Bq m-3','CAACL'],
    713'19-191':['Reserved','unknown','unknown'],
    714'192-254':['Reserved for Local Use','unknown','unknown'],
    715'255':['Missing','unknown','unknown'],
    716}
    717table_4_2_0_19  = {
    718'0':['Visibility','m','VIS'],
    719'1':['Albedo','%','ALBDO'],
    720'2':['Thunderstorm Probability','%','TSTM'],
    721'3':['Mixed Layer Depth','m','MIXHT'],
    722'4':['Volcanic Ash','See Table 4.206','VOLASH'],
    723'5':['Icing Top','m','ICIT'],
    724'6':['Icing Base','m','ICIB'],
    725'7':['Icing','See Table 4.207','ICI'],
    726'8':['Turbulence Top','m','TURBT'],
    727'9':['Turbulence Base','m','TURBB'],
    728'10':['Turbulence','See Table 4.208','TURB'],
    729'11':['Turbulent Kinetic Energy','J kg-1','TKE'],
    730'12':['Planetary Boundary Layer Regime','See Table 4.209','PBLREG'],
    731'13':['Contrail Intensity','See Table 4.210','CONTI'],
    732'14':['Contrail Engine Type','See Table 4.211','CONTET'],
    733'15':['Contrail Top','m','CONTT'],
    734'16':['Contrail Base','m','CONTB'],
    735'17':['Maximum Snow Albedosee Note 1','%','MXSALB'],
    736'18':['Snow-Free Albedo','%','SNFALB'],
    737'19':['Snow Albedo','%','SALBD'],
    738'20':['Icing','%','ICIP'],
    739'21':['In-Cloud Turbulence','%','CTP'],
    740'22':['Clear Air Turbulence (CAT)','%','CAT'],
    741'23':['Supercooled Large Droplet Probabilitysee Note 2','%','SLDP'],
    742'24':['Convective Turbulent Kinetic Energy','J kg-1','CONTKE'],
    743'25':['Weather','See Table 4.225','WIWW'],
    744'26':['Convective Outlook','See Table 4.224','CONVO'],
    745'27':['Icing Scenario','See Table 4.227','ICESC'],
    746'28':['Mountain Wave Turbulence (Eddy Dissipation Rate)','m2/3 s-1','MWTURB'],
    747'29':['Clear Air Turbulence (CAT) (Eddy Dissipation Rate)','m2/3 s-1','CATEDR'],
    748'30':['Eddy Dissipation Parameter','m2/3 s-1','EDPARM'],
    749'31':['Maximum of Eddy Dissipation Parameter in Layer','m2/3 s-1','MXEDPRM'],
    750'32':['Highest Freezing Level','m','HIFREL'],
    751'33':['Visibility Through Liquid Fog','m','VISLFOG'],
    752'34':['Visibility Through Ice Fog','m','VISIFOG'],
    753'35':['Visibility Through Blowing Snow','m','VISBSN'],
    754'36':['Presence of Snow Squalls','See Table 4.222','PSNOWS'],
    755'37':['Icing Severity','See Table 4.228','ICESEV'],
    756'38':['Sky transparency index','See Table 4.214','SKYIDX'],
    757'39':['Seeing index','See Table 4.214','SEEINDEX'],
    758'40':['Snow level','m','SNOWLVL'],
    759'41-191':['Reserved','unknown','unknown'],
    760'192-254':['Reserved for Local Use','unknown','unknown'],
    761'192':['Maximum Snow Albedo','%','MXSALB'],
    762'193':['Snow-Free Albedo','%','SNFALB'],
    763'194':['Slight risk convective outlook','categorical','SRCONO'],
    764'195':['Moderate risk convective outlook','categorical','MRCONO'],
    765'196':['High risk convective outlook','categorical','HRCONO'],
    766'197':['Tornado probability','%','TORPROB'],
    767'198':['Hail probability','%','HAILPROB'],
    768'199':['Wind probability','%','WINDPROB'],
    769'200':['Significant Tornado probability','%','STORPROB'],
    770'201':['Significant Hail probability','%','SHAILPRO'],
    771'202':['Significant Wind probability','%','SWINDPRO'],
    772'203':['Categorical Thunderstorm','Code table 4.222','TSTMC'],
    773'204':['Number of mixed layers next to surface','integer','MIXLY'],
    774'205':['Flight Category','unknown','FLGHT'],
    775'206':['Confidence - Ceiling','unknown','CICEL'],
    776'207':['Confidence - Visibility','unknown','CIVIS'],
    777'208':['Confidence - Flight Category','unknown','CIFLT'],
    778'209':['Low-Level aviation interest','unknown','LAVNI'],
    779'210':['High-Level aviation interest','unknown','HAVNI'],
    780'211':['Visible, Black Sky Albedo','%','SBSALB'],
    781'212':['Visible, White Sky Albedo','%','SWSALB'],
    782'213':['Near IR, Black Sky Albedo','%','NBSALB'],
    783'214':['Near IR, White Sky Albedo','%','NWSALB'],
    784'215':['Total Probability of Severe Thunderstorms (Days 2,3)','%','PRSVR'],
    785'216':['Total Probability of Extreme Severe Thunderstorms (Days 2,3)','%','PRSIGSVR'],
    786'217':['Supercooled Large Droplet (SLD) Icingsee Note 2','See Table 4.207','SIPD'],
    787'218':['Radiative emissivity','unknown','EPSR'],
    788'219':['Turbulence Potential Forecast Index','unknown','TPFI'],
    789'220':['Categorical Severe Thunderstorm','Code table 4.222','SVRTS'],
    790'221':['Probability of Convection','%','PROCON'],
    791'222':['Convection Potential','Code table 4.222','CONVP'],
    792'223-231':['Reserved','unknown','unknown'],
    793'232':['Volcanic Ash Forecast Transport and Dispersion','log10 (kg m-3)','VAFTD'],
    794'233':['Icing probability','non-dim','ICPRB'],
    795'234':['Icing Severity','non-dim','ICSEV'],
    796'235':['Joint Fire Weather Probability','%','JFWPRB'],
    797'236':['Snow Level','m','SNOWLVL'],
    798'237':['Dry Thunderstorm Probability','%','DRYTPROB'],
    799'238':['Ellrod Index','unknown','ELLINX'],
    800'239':['Craven-Wiedenfeld Aggregate Severe Parameter','Numeric','CWASP'],
    801'255':['Missing','unknown','unknown'],
    802}
    803table_4_2_0_20  = {
    804'0':['Mass Density (Concentration)','kg m-3','MASSDEN'],
    805'1':['Column-Integrated Mass Density','kg m-2','COLMD'],
    806'2':['Mass Mixing Ratio (Mass Fraction in Air)','kg kg-1','MASSMR'],
    807'3':['Atmosphere Emission Mass Flux','kg m-2s-1','AEMFLX'],
    808'4':['Atmosphere Net Production Mass Flux','kg m-2s-1','ANPMFLX'],
    809'5':['Atmosphere Net Production And Emision Mass Flux','kg m-2s-1','ANPEMFLX'],
    810'6':['Surface Dry Deposition Mass Flux','kg m-2s-1','SDDMFLX'],
    811'7':['Surface Wet Deposition Mass Flux','kg m-2s-1','SWDMFLX'],
    812'8':['Atmosphere Re-Emission Mass Flux','kg m-2s-1','AREMFLX'],
    813'9':['Wet Deposition by Large-Scale Precipitation Mass Flux','kg m-2s-1','WLSMFLX'],
    814'10':['Wet Deposition by Convective Precipitation Mass Flux','kg m-2s-1','WDCPMFLX'],
    815'11':['Sedimentation Mass Flux','kg m-2s-1','SEDMFLX'],
    816'12':['Dry Deposition Mass Flux','kg m-2s-1','DDMFLX'],
    817'13':['Transfer From Hydrophobic to Hydrophilic','kg kg-1s-1','TRANHH'],
    818'14':['Transfer From SO2 (Sulphur Dioxide) to SO4 (Sulphate)','kg kg-1s-1','TRSDS'],
    819'15':['Dry deposition velocity','m s-1','DDVEL'],
    820'16':['Mass mixing ratio with respect to dry air','kg kg-1','MSSRDRYA'],
    821'17':['Mass mixing ratio with respect to wet air','kg kg-1','MSSRWETA'],
    822'18-49':['Reserved','unknown','unknown'],
    823'50':['Amount in Atmosphere','mol','AIA'],
    824'51':['Concentration In Air','mol m-3','CONAIR'],
    825'52':['Volume Mixing Ratio (Fraction in Air)','mol mol-1','VMXR'],
    826'53':['Chemical Gross Production Rate of Concentration','mol m-3s-1','CGPRC'],
    827'54':['Chemical Gross Destruction Rate of Concentration','mol m-3s-1','CGDRC'],
    828'55':['Surface Flux','mol m-2s-1','SFLUX'],
    829'56':['Changes Of Amount in Atmosphere','mol s-1','COAIA'],
    830'57':['Total Yearly Average Burden of The Atmosphere>','mol','TYABA'],
    831'58':['Total Yearly Average Atmospheric Loss','mol s-1','TYAAL'],
    832'59':['Aerosol Number Concentration','m-3','ANCON'],
    833'60':['Aerosol Specific Number Concentration','kg-1','ASNCON'],
    834'61':['Maximum of Mass Density','kg m-3','MXMASSD'],
    835'62':['Height of Mass Density','m','HGTMD'],
    836'63':['Column-Averaged Mass Density in Layer','kg m-3','CAVEMDL'],
    837'64':['Mole fraction with respect to dry air','mol mol-1','MOLRDRYA'],
    838'65':['Mole fraction with respect to wet air','mol mol-1','MOLRWETA'],
    839'66':['Column-integrated in-cloud scavenging rate by precipitation','kg m-2 s-1','CINCLDSP'],
    840'67':['Column-integrated below-cloud scavenging rate by precipitation','kg m-2 s-1','CBLCLDSP'],
    841'68':['Column-integrated release rate from evaporating precipitation','kg m-2 s-1','CIRELREP'],
    842'69':['Column-integrated in-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CINCSLSP'],
    843'70':['Column-integrated below-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CBECSLSP'],
    844'71':['Column-integrated release rate from evaporating large-scale precipitation','kg m-2 s-1','CRERELSP'],
    845'72':['Column-integrated in-cloud scavenging rate by convective precipitation','kg m-2 s-1','CINCSRCP'],
    846'73':['Column-integrated below-cloud scavenging rate by convective precipitation','kg m-2 s-1','CBLCSRCP'],
    847'74':['Column-integrated release rate from evaporating convective precipitation','kg m-2 s-1','CIRERECP'],
    848'75':['Wildfire flux','kg m-2 s-1','WFIREFLX'],
    849'76':['Emission Rate','kg kg-1 s-1','EMISFLX'],
    850'77':['Surface Emission flux','kg m-2 s-1','SFCEFLX'],
    851'78-99':['Reserved','unknown','unknown'],
    852'100':['Surface Area Density (Aerosol)','m-1','SADEN'],
    853'101':['Vertical Visual Range','m','ATMTK'],
    854'102':['Aerosol Optical Thickness','Numeric','AOTK'],
    855'103':['Single Scattering Albedo','Numeric','SSALBK'],
    856'104':['Asymmetry Factor','Numeric','ASYSFK'],
    857'105':['Aerosol Extinction Coefficient','m-1','AECOEF'],
    858'106':['Aerosol Absorption Coefficient','m-1','AACOEF'],
    859'107':['Aerosol Lidar Backscatter from Satellite','m-1sr-1','ALBSAT'],
    860'108':['Aerosol Lidar Backscatter from the Ground','m-1sr-1','ALBGRD'],
    861'109':['Aerosol Lidar Extinction from Satellite','m-1','ALESAT'],
    862'110':['Aerosol Lidar Extinction from the Ground','m-1','ALEGRD'],
    863'111':['Angstrom Exponent','Numeric','ANGSTEXP'],
    864'112':['Scattering Aerosol Optical Thickness','Numeric','SCTAOTK'],
    865'113-191':['Reserved','unknown','unknown'],
    866'192-254':['Reserved for Local Use','unknown','unknown'],
    867'255':['Missing','unknown','unknown'],
    868}
    869table_4_2_0_190  = {
    870'0':['Arbitrary Text String','CCITTIA5','ATEXT'],
    871'1-191':['Reserved','unknown','unknown'],
    872'192-254':['Reserved for Local Use','unknown','unknown'],
    873'255':['Missing','unknown','unknown'],
    874}
    875table_4_2_0_191  = {
    876'0':['Seconds prior to initial reference time (defined in Section 1)','s','TSEC'],
    877'1':['Geographical Latitude','° N','GEOLAT'],
    878'2':['Geographical Longitude','° E','GEOLON'],
    879'3':['Days Since Last Observation','d','DSLOBS'],
    880'4-191':['Reserved','unknown','unknown'],
    881'192-254':['Reserved for Local Use','unknown','unknown'],
    882'192':['Latitude (-90 to 90)','°','NLAT'],
    883'193':['East Longitude (0 to 360)','°','ELON'],
    884'194':['Seconds prior to initial reference time','s','RTSEC'],
    885'195':['Model Layer number (From bottom up)','unknown','MLYNO'],
    886'196':['Latitude (nearest neighbor) (-90 to 90)','°','NLATN'],
    887'197':['East Longitude (nearest neighbor) (0 to 360)','°','ELONN'],
    888'255':['Missing','unknown','unknown'],
    889}
    890table_4_2_0_192  = {
    891'1':['Covariance between zonal and meridional components of the wind. Defined as [uv]-[u][v], where "[]" indicates the mean over the indicated time span.','m2/s2','COVMZ'],
    892'2':['Covariance between zonal component of the wind and temperature. Defined as [uT]-[u][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTZ'],
    893'3':['Covariance between meridional component of the wind and temperature. Defined as [vT]-[v][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTM'],
    894'4':['Covariance between temperature and vertical component of the wind. Defined as [wT]-[w][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTW'],
    895'5':['Covariance between zonal and zonal components of the wind. Defined as [uu]-[u][u], where "[]" indicates the mean over the indicated time span.','m2/s2','COVZZ'],
    896'6':['Covariance between meridional and meridional components of the wind. Defined as [vv]-[v][v], where "[]" indicates the mean over the indicated time span.','m2/s2','COVMM'],
    897'7':['Covariance between specific humidity and zonal components of the wind. Defined as [uq]-[u][q], where "[]" indicates the mean over the indicated time span.','kg/kg*m/s','COVQZ'],
    898'8':['Covariance between specific humidity and meridional components of the wind. Defined as [vq]-[v][q], where "[]" indicates the mean over the indicated time span.','kg/kg*m/s','COVQM'],
    899'9':['Covariance between temperature and vertical components of the wind. Defined as [ΩT]-[Ω][T], where "[]" indicates the mean over the indicated time span.','K*Pa/s','COVTVV'],
    900'10':['Covariance between specific humidity and vertical components of the wind. Defined as [Ωq]-[Ω][q], where "[]" indicates the mean over the indicated time span.','kg/kg*Pa/s','COVQVV'],
    901'11':['Covariance between surface pressure and surface pressure. Defined as [Psfc]-[Psfc][Psfc], where "[]" indicates the mean over the indicated time span.','Pa*Pa','COVPSPS'],
    902'12':['Covariance between specific humidity and specific humidy. Defined as [qq]-[q][q], where "[]" indicates the mean over the indicated time span.','kg/kg*kg/kg','COVQQ'],
    903'13':['Covariance between vertical and vertical components of the wind. Defined as [ΩΩ]-[Ω][Ω], where "[]" indicates the mean over the indicated time span.','Pa2/s2','COVVVVV'],
    904'14':['Covariance between temperature and temperature. Defined as [TT]-[T][T], where "[]" indicates the mean over the indicated time span.','K*K','COVTT'],
    905'255':['Missing','unknown','unknown'],
    906}
    907
    908# ----------------------------------------------------------------------------------------
    909# Source: https://github.com/NOAA-EMC/NCEPLIBS-wgrib2/blob/develop/wgrib2/NDFD_gribtab.dat
    910# ----------------------------------------------------------------------------------------
    911table_4_2_0_0_ndfd = {
    912'193':['Apparent Temperature','K','APPT'],
    913}
    914table_4_2_0_1_ndfd = {
    915'192':['Weather Information','WxInfo','WX'],
    916}
    917table_4_2_0_19_ndfd = {
    918'194':['Convective Hazard Outlook','categorical','CONVOUTLOOK'],
    919'197':['Probability of Tornado','%','PTORNADO'],
    920'198':['Probability of Hail','%','PHAIL'],
    921'199':['Probability of Damaging Wind','%','PWIND'],
    922'200':['Probability of Extreme Tornado','%','PXTRMTORN'],
    923'201':['Probability of Extreme Hail','%','PXTRMHAIL'],
    924'202':['Probability of Extreme Wind','%','PXTRMWIND'],
    925'215':['Total Probability of Severe Thunderstorms','%','TOTALSVRPROB'],
    926'216':['Total Probability of Extreme Severe Thunderstorms','%','TOTALXTRMPROB'],
    927'217':['Watch Warning Advisory','WxInfo','WWA'],
    928}
    929table_4_2_0_192_ndfd = {
    930'192':['Critical Fire Weather','','FIREWX'],
    931'194':['Dry Lightning','','DRYLIGHTNING'],
    932}